@@ -90,11 +90,6 @@ def test_german_defanging():
     assert ioc_fanger.fang(s) == "me@example.com"
 
 
-def test_issue_16():
-    s = "www[.example.com"
-    assert ioc_fanger.fang(s) == "www.example.com"
-
-
 def test_issue_24():
     s = "seasharpee"
     assert ioc_fanger.fang(s) == "seasharpee"
@@ -126,17 +121,23 @@ def test_odd_brackets():
     s = "www].[example].[com"
     assert ioc_fanger.fang(s) == "www.example.com"
 
+
+def test__punctuation_with_single_bracket__not_changed():
+    """These examples used to be fanged, but we removed support for fanging punctuation with a single bracket around it in #49."""
     s = "www.[example.[com"
-    assert ioc_fanger.fang(s) == "www.example.com"
+    assert ioc_fanger.fang(s) == s
 
     s = "www.]example.]com"
-    assert ioc_fanger.fang(s) == "www.example.com"
+    assert ioc_fanger.fang(s) == s
 
     s = "www[.example[.com"
-    assert ioc_fanger.fang(s) == "www.example.com"
+    assert ioc_fanger.fang(s) == s
 
     s = "www].example].com"
-    assert ioc_fanger.fang(s) == "www.example.com"
+    assert ioc_fanger.fang(s) == s
+
+    s = "www],example),com"
+    assert ioc_fanger.fang(s) == s
 
 
 def test_odd_misc():
@@ -241,23 +242,6 @@ def test_odd_schemes():
     s = "(https)://example.com/test.php"
     assert ioc_fanger.fang(s) == "https://example.com/test.php"
 
-    s = "http!://example.com/test.php"
-    assert ioc_fanger.fang(s) == "https://example.com/test.php"
-    s = "https!://example.com/test.php"
-    assert ioc_fanger.fang(s) == "https://example.com/test.php"
-    s = "https@://example.com/test.php"
-    assert ioc_fanger.fang(s) == "https://example.com/test.php"
-    s = "httpA://example.com/test.php"
-    assert ioc_fanger.fang(s) == "https://example.com/test.php"
-    s = "https&://example.com/test.php"
-    assert ioc_fanger.fang(s) == "https://example.com/test.php"
-
-    s = "https&://example.com/test.php https://example.com/test.php http&://example.com/test.php xxXpA://example.com/test.php"
-    assert (
-        ioc_fanger.fang(s)
-        == "https://example.com/test.php https://example.com/test.php https://example.com/test.php https://example.com/test.php"
-    )
-
     s = "hxxps[://]example[.]com/test[.]html"
     assert ioc_fanger.fang(s) == "https://example.com/test.html"
 
@@ -373,8 +357,9 @@ def test_odd_hXXp_replacement():
     )
 
     # this is based on the text of an incident found here: https://app.threatconnect.com/auth/incident/incident.xhtml?incident=2952580883&owner=Technical%20Blogs%20and%20Reports#/
+    # update (aug 2022): this used to be fanged, but we are no longer fanging this
     s = "domain (www.example.com)."
-    assert ioc_fanger.fang(s) == "domain www.example.com)."
+    assert ioc_fanger.fang(s) == s
 
 
 def test_markdown_fanging():
@@ -391,60 +376,52 @@ def test_debug():
     assert ioc_fanger.fang(s, debug=True) == "192.168.4.2"
 
 
-def test_issue_34():
-    s = """[Researcher email address].
-
-Best Regards,"""
-    result = ioc_fanger.fang(s)
-    print(result)
-    assert (
-        result
-        == """[Researcher email address.
-
-Best Regards,"""
-    )
-
-
 def test_issue_46():
-    s = 'div><div><br></div><div>hxxp://zeplin[.]atwebpages[.]com/inter[.]php</div><'
+    s = "div><div><br></div><div>hxxp://zeplin[.]atwebpages[.]com/inter[.]php</div><"
     result = ioc_fanger.fang(s)
-    assert result == 'div><div><br></div><div>http://zeplin.atwebpages.com/inter.php</div><'
+    assert result == "div><div><br></div><div>http://zeplin.atwebpages.com/inter.php</div><"
 
 
 def test_issue_47():
-    s = 'a. [b'
+    s = "a. [b"
     result = ioc_fanger.fang(s)
-    assert result == 'a. [b'
+    assert result == "a. [b"
 
-    s = 'a. (b'
+    s = "a. (b"
     result = ioc_fanger.fang(s)
-    assert result == 'a. (b'
+    assert result == "a. (b"
 
 
 def test_issue_53__percent_encoded_urls_fanged_properly():
     """Testing to make sure percent encoded URLs are properly fanged."""
-    s = 'https://asf.goole.com/mail?url=http%3A%2F%2Ffreasdfuewriter.com%2Fcs%2Fimage%2FCommerciaE.jpg&t=1575955624&ymreqid=733bc9eb-e8f-34cb-1cb5-120010019e00&sig=x2Pa2oOYxanG52s4vyCEFg--~Chttp://uniddloos.zddfdd.org/CBA0019_file_00002_pdf.zip'
+    s = "https://asf.goole.com/mail?url=http%3A%2F%2Ffreasdfuewriter.com%2Fcs%2Fimage%2FCommerciaE.jpg&t=1575955624&ymreqid=733bc9eb-e8f-34cb-1cb5-120010019e00&sig=x2Pa2oOYxanG52s4vyCEFg--~Chttp://uniddloos.zddfdd.org/CBA0019_file_00002_pdf.zip"
     result = ioc_fanger.fang(s)
     assert (
         result
-        == 'https://asf.goole.com/mail?url=http%3A%2F%2Ffreasdfuewriter.com%2Fcs%2Fimage%2FCommerciaE.jpg&t=1575955624&ymreqid=733bc9eb-e8f-34cb-1cb5-120010019e00&sig=x2Pa2oOYxanG52s4vyCEFg--~Chttp://uniddloos.zddfdd.org/CBA0019_file_00002_pdf.zip'
+        == "https://asf.goole.com/mail?url=http%3A%2F%2Ffreasdfuewriter.com%2Fcs%2Fimage%2FCommerciaE.jpg&t=1575955624&ymreqid=733bc9eb-e8f-34cb-1cb5-120010019e00&sig=x2Pa2oOYxanG52s4vyCEFg--~Chttp://uniddloos.zddfdd.org/CBA0019_file_00002_pdf.zip"
     )
 
 
 def test_issue_53__urls_in_query_strings_fanged():
     """Make sure URLs in query strings are properly fanged."""
     # imagining s is part of a query string, make sure s is unchanged
-    s = '--~Chttp://uniddloos.zddfdd.org/CBA0019_file_00002_pdf.zip'
+    s = "--~Chttp://uniddloos.zddfdd.org/CBA0019_file_00002_pdf.zip"
     result = ioc_fanger.fang(s)
-    assert result == '--~Chttp://uniddloos.zddfdd.org/CBA0019_file_00002_pdf.zip'
+    assert result == "--~Chttp://uniddloos.zddfdd.org/CBA0019_file_00002_pdf.zip"
 
     # imagining s is part of a query string, make sure s is unchanged
-    s = '--~Chttps://uniddloos.zddfdd.org/CBA0019_file_00002_pdf.zip'
+    s = "--~Chttps://uniddloos.zddfdd.org/CBA0019_file_00002_pdf.zip"
     result = ioc_fanger.fang(s)
-    assert result == '--~Chttps://uniddloos.zddfdd.org/CBA0019_file_00002_pdf.zip'
+    assert result == "--~Chttps://uniddloos.zddfdd.org/CBA0019_file_00002_pdf.zip"
 
 
 def test_issue_52__escaped_periods():
-    s = 'foo 1<.>1<.>1<.>1 bar.'
+    s = "foo 1<.>1<.>1<.>1 bar."
     result = ioc_fanger.fang(s)
-    assert result == 'foo 1.1.1.1 bar.'
+    assert result == "foo 1.1.1.1 bar."
+
+
+def test_alternative_schemes_preserved():
+    s = "ldap://example.com/a"
+    result = ioc_fanger.fang(s)
+    assert result == "ldap://example.com/a"
